# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class StartRayClusterRequest(DaraModel):
    def __init__(
        self,
        client_token: str = None,
    ):
        self.client_token = client_token

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client_token is not None:
            result['clientToken'] = self.client_token

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('clientToken') is not None:
            self.client_token = m.get('clientToken')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CancelKyuubiSparkApplicationRequest(DaraModel):
    def __init__(
        self,
        region_id: str = None,
    ):
        self.region_id = region_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class ListNetworkServicesResponseBody(DaraModel):
    def __init__(
        self,
        max_results: int = None,
        network_services: List[main_models.ListNetworkServicesResponseBodyNetworkServices] = None,
        next_token: str = None,
        queues: List[main_models.ListNetworkServicesResponseBodyQueues] = None,
        request_id: str = None,
        total_count: int = None,
    ):
        # 一次获取的最大记录数。
        self.max_results = max_results
        self.network_services = network_services
        # 下一页TOKEN。
        self.next_token = next_token
        self.queues = queues
        self.request_id = request_id
        # 记录总数。
        self.total_count = total_count

    def validate(self):
        if self.network_services:
            for v1 in self.network_services:
                 if v1:
                    v1.validate()
        if self.queues:
            for v1 in self.queues:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.max_results is not None:
            result['maxResults'] = self.max_results

        result['networkServices'] = []
        if self.network_services is not None:
            for k1 in self.network_services:
                result['networkServices'].append(k1.to_map() if k1 else None)

        if self.next_token is not None:
            result['nextToken'] = self.next_token

        result['queues'] = []
        if self.queues is not None:
            for k1 in self.queues:
                result['queues'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.total_count is not None:
            result['totalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('maxResults') is not None:
            self.max_results = m.get('maxResults')

        self.network_services = []
        if m.get('networkServices') is not None:
            for k1 in m.get('networkServices'):
                temp_model = main_models.ListNetworkServicesResponseBodyNetworkServices()
                self.network_services.append(temp_model.from_map(k1))

        if m.get('nextToken') is not None:
            self.next_token = m.get('nextToken')

        self.queues = []
        if m.get('queues') is not None:
            for k1 in m.get('queues'):
                temp_model = main_models.ListNetworkServicesResponseBodyQueues()
                self.queues.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('totalCount') is not None:
            self.total_count = m.get('totalCount')

        return self

class ListNetworkServicesResponseBodyQueues(DaraModel):
    def __init__(
        self,
        name: str = None,
        network_service_id: str = None,
        state: str = None,
        state_change_reason: main_models.ListNetworkServicesResponseBodyQueuesStateChangeReason = None,
        type: str = None,
        vpc_id: str = None,
        vswitch_ids: List[str] = None,
        workspace_id: str = None,
    ):
        self.name = name
        self.network_service_id = network_service_id
        self.state = state
        self.state_change_reason = state_change_reason
        self.type = type
        self.vpc_id = vpc_id
        self.vswitch_ids = vswitch_ids
        self.workspace_id = workspace_id

    def validate(self):
        if self.state_change_reason:
            self.state_change_reason.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        if self.network_service_id is not None:
            result['networkServiceId'] = self.network_service_id

        if self.state is not None:
            result['state'] = self.state

        if self.state_change_reason is not None:
            result['stateChangeReason'] = self.state_change_reason.to_map()

        if self.type is not None:
            result['type'] = self.type

        if self.vpc_id is not None:
            result['vpcId'] = self.vpc_id

        if self.vswitch_ids is not None:
            result['vswitchIds'] = self.vswitch_ids

        if self.workspace_id is not None:
            result['workspaceId'] = self.workspace_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('networkServiceId') is not None:
            self.network_service_id = m.get('networkServiceId')

        if m.get('state') is not None:
            self.state = m.get('state')

        if m.get('stateChangeReason') is not None:
            temp_model = main_models.ListNetworkServicesResponseBodyQueuesStateChangeReason()
            self.state_change_reason = temp_model.from_map(m.get('stateChangeReason'))

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('vpcId') is not None:
            self.vpc_id = m.get('vpcId')

        if m.get('vswitchIds') is not None:
            self.vswitch_ids = m.get('vswitchIds')

        if m.get('workspaceId') is not None:
            self.workspace_id = m.get('workspaceId')

        return self

class ListNetworkServicesResponseBodyQueuesStateChangeReason(DaraModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
    ):
        self.code = code
        self.message = message

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['code'] = self.code

        if self.message is not None:
            result['message'] = self.message

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('code') is not None:
            self.code = m.get('code')

        if m.get('message') is not None:
            self.message = m.get('message')

        return self

class ListNetworkServicesResponseBodyNetworkServices(DaraModel):
    def __init__(
        self,
        name: str = None,
        network_service_id: str = None,
        state: str = None,
        state_change_reason: main_models.ListNetworkServicesResponseBodyNetworkServicesStateChangeReason = None,
        type: str = None,
        vpc_id: str = None,
        vswitch_ids: List[str] = None,
        workspace_id: str = None,
    ):
        self.name = name
        self.network_service_id = network_service_id
        self.state = state
        self.state_change_reason = state_change_reason
        self.type = type
        # VPC id。
        self.vpc_id = vpc_id
        self.vswitch_ids = vswitch_ids
        self.workspace_id = workspace_id

    def validate(self):
        if self.state_change_reason:
            self.state_change_reason.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        if self.network_service_id is not None:
            result['networkServiceId'] = self.network_service_id

        if self.state is not None:
            result['state'] = self.state

        if self.state_change_reason is not None:
            result['stateChangeReason'] = self.state_change_reason.to_map()

        if self.type is not None:
            result['type'] = self.type

        if self.vpc_id is not None:
            result['vpcId'] = self.vpc_id

        if self.vswitch_ids is not None:
            result['vswitchIds'] = self.vswitch_ids

        if self.workspace_id is not None:
            result['workspaceId'] = self.workspace_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('networkServiceId') is not None:
            self.network_service_id = m.get('networkServiceId')

        if m.get('state') is not None:
            self.state = m.get('state')

        if m.get('stateChangeReason') is not None:
            temp_model = main_models.ListNetworkServicesResponseBodyNetworkServicesStateChangeReason()
            self.state_change_reason = temp_model.from_map(m.get('stateChangeReason'))

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('vpcId') is not None:
            self.vpc_id = m.get('vpcId')

        if m.get('vswitchIds') is not None:
            self.vswitch_ids = m.get('vswitchIds')

        if m.get('workspaceId') is not None:
            self.workspace_id = m.get('workspaceId')

        return self

class ListNetworkServicesResponseBodyNetworkServicesStateChangeReason(DaraModel):
    def __init__(
        self,
        code: str = None,
        message: str = None,
    ):
        self.code = code
        self.message = message

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['code'] = self.code

        if self.message is not None:
            result['message'] = self.message

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('code') is not None:
            self.code = m.get('code')

        if m.get('message') is not None:
            self.message = m.get('message')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class CreateNetworkServiceRequest(DaraModel):
    def __init__(
        self,
        client_token: str = None,
        name: str = None,
        security_group_id: str = None,
        type: str = None,
        vpc_id: str = None,
        vswitch_ids: List[str] = None,
        region_id: str = None,
    ):
        self.client_token = client_token
        self.name = name
        self.security_group_id = security_group_id
        self.type = type
        # VPC id。
        self.vpc_id = vpc_id
        self.vswitch_ids = vswitch_ids
        self.region_id = region_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.client_token is not None:
            result['clientToken'] = self.client_token

        if self.name is not None:
            result['name'] = self.name

        if self.security_group_id is not None:
            result['securityGroupId'] = self.security_group_id

        if self.type is not None:
            result['type'] = self.type

        if self.vpc_id is not None:
            result['vpcId'] = self.vpc_id

        if self.vswitch_ids is not None:
            result['vswitchIds'] = self.vswitch_ids

        if self.region_id is not None:
            result['regionId'] = self.region_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('clientToken') is not None:
            self.client_token = m.get('clientToken')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('securityGroupId') is not None:
            self.security_group_id = m.get('securityGroupId')

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('vpcId') is not None:
            self.vpc_id = m.get('vpcId')

        if m.get('vswitchIds') is not None:
            self.vswitch_ids = m.get('vswitchIds')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_emr_serverless_spark20230808 import models as main_models
from darabonba.model import DaraModel

class CacheCluster(DaraModel):
    def __init__(
        self,
        binded_workspaces: List[str] = None,
        cachesets: List[main_models.CacheClusterCachesets] = None,
        cluster_id: str = None,
        configuration: str = None,
        configurations: List[main_models.CacheClusterConfigurations] = None,
        creator: str = None,
        gmt_created: int = None,
        gmt_modified: int = None,
        modifier: str = None,
        name: str = None,
        payment_type: str = None,
        region_id: str = None,
        resource_spec: main_models.CacheClusterResourceSpec = None,
        state: str = None,
        used_resource_spec: main_models.CacheClusterUsedResourceSpec = None,
    ):
        self.binded_workspaces = binded_workspaces
        self.cachesets = cachesets
        self.cluster_id = cluster_id
        self.configuration = configuration
        self.configurations = configurations
        self.creator = creator
        self.gmt_created = gmt_created
        self.gmt_modified = gmt_modified
        self.modifier = modifier
        self.name = name
        self.payment_type = payment_type
        self.region_id = region_id
        self.resource_spec = resource_spec
        self.state = state
        self.used_resource_spec = used_resource_spec

    def validate(self):
        if self.cachesets:
            for v1 in self.cachesets:
                 if v1:
                    v1.validate()
        if self.configurations:
            for v1 in self.configurations:
                 if v1:
                    v1.validate()
        if self.resource_spec:
            self.resource_spec.validate()
        if self.used_resource_spec:
            self.used_resource_spec.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.binded_workspaces is not None:
            result['bindedWorkspaces'] = self.binded_workspaces

        result['cachesets'] = []
        if self.cachesets is not None:
            for k1 in self.cachesets:
                result['cachesets'].append(k1.to_map() if k1 else None)

        if self.cluster_id is not None:
            result['clusterId'] = self.cluster_id

        if self.configuration is not None:
            result['configuration'] = self.configuration

        result['configurations'] = []
        if self.configurations is not None:
            for k1 in self.configurations:
                result['configurations'].append(k1.to_map() if k1 else None)

        if self.creator is not None:
            result['creator'] = self.creator

        if self.gmt_created is not None:
            result['gmtCreated'] = self.gmt_created

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.modifier is not None:
            result['modifier'] = self.modifier

        if self.name is not None:
            result['name'] = self.name

        if self.payment_type is not None:
            result['paymentType'] = self.payment_type

        if self.region_id is not None:
            result['regionId'] = self.region_id

        if self.resource_spec is not None:
            result['resourceSpec'] = self.resource_spec.to_map()

        if self.state is not None:
            result['state'] = self.state

        if self.used_resource_spec is not None:
            result['usedResourceSpec'] = self.used_resource_spec.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('bindedWorkspaces') is not None:
            self.binded_workspaces = m.get('bindedWorkspaces')

        self.cachesets = []
        if m.get('cachesets') is not None:
            for k1 in m.get('cachesets'):
                temp_model = main_models.CacheClusterCachesets()
                self.cachesets.append(temp_model.from_map(k1))

        if m.get('clusterId') is not None:
            self.cluster_id = m.get('clusterId')

        if m.get('configuration') is not None:
            self.configuration = m.get('configuration')

        self.configurations = []
        if m.get('configurations') is not None:
            for k1 in m.get('configurations'):
                temp_model = main_models.CacheClusterConfigurations()
                self.configurations.append(temp_model.from_map(k1))

        if m.get('creator') is not None:
            self.creator = m.get('creator')

        if m.get('gmtCreated') is not None:
            self.gmt_created = m.get('gmtCreated')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('modifier') is not None:
            self.modifier = m.get('modifier')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('paymentType') is not None:
            self.payment_type = m.get('paymentType')

        if m.get('regionId') is not None:
            self.region_id = m.get('regionId')

        if m.get('resourceSpec') is not None:
            temp_model = main_models.CacheClusterResourceSpec()
            self.resource_spec = temp_model.from_map(m.get('resourceSpec'))

        if m.get('state') is not None:
            self.state = m.get('state')

        if m.get('usedResourceSpec') is not None:
            temp_model = main_models.CacheClusterUsedResourceSpec()
            self.used_resource_spec = temp_model.from_map(m.get('usedResourceSpec'))

        return self

class CacheClusterUsedResourceSpec(DaraModel):
    def __init__(
        self,
        band_width: int = None,
        storage: int = None,
    ):
        self.band_width = band_width
        self.storage = storage

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.band_width is not None:
            result['bandWidth'] = self.band_width

        if self.storage is not None:
            result['storage'] = self.storage

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('bandWidth') is not None:
            self.band_width = m.get('bandWidth')

        if m.get('storage') is not None:
            self.storage = m.get('storage')

        return self

class CacheClusterResourceSpec(DaraModel):
    def __init__(
        self,
        band_width: int = None,
        storage: int = None,
    ):
        self.band_width = band_width
        self.storage = storage

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.band_width is not None:
            result['bandWidth'] = self.band_width

        if self.storage is not None:
            result['storage'] = self.storage

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('bandWidth') is not None:
            self.band_width = m.get('bandWidth')

        if m.get('storage') is not None:
            self.storage = m.get('storage')

        return self

class CacheClusterConfigurations(DaraModel):
    def __init__(
        self,
        content: str = None,
        name: str = None,
    ):
        self.content = content
        self.name = name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.content is not None:
            result['content'] = self.content

        if self.name is not None:
            result['name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('content') is not None:
            self.content = m.get('content')

        if m.get('name') is not None:
            self.name = m.get('name')

        return self



class CacheClusterCachesets(DaraModel):
    def __init__(
        self,
        name: str = None,
        path: str = None,
    ):
        self.name = name
        self.path = path

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        if self.path is not None:
            result['path'] = self.path

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('path') is not None:
            self.path = m.get('path')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateWorkspaceResponseBody(DaraModel):
    def __init__(
        self,
        operation_id: str = None,
        request_id: str = None,
        workspace_id: str = None,
    ):
        # The operation ID.
        self.operation_id = operation_id
        # The request ID.
        self.request_id = request_id
        # The workspace ID.
        self.workspace_id = workspace_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.operation_id is not None:
            result['operationId'] = self.operation_id

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.workspace_id is not None:
            result['workspaceId'] = self.workspace_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('operationId') is not None:
            self.operation_id = m.get('operationId')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('workspaceId') is not None:
            self.workspace_id = m.get('workspaceId')

        return self

